StdResErrorCond enum

Available Precondition/Postcondition defined in RFC4918. see: https://datatracker.ietf.org/doc/html/rfc4918#section-16

Inheritance
Available extensions

Values

lockTokenMatchesRequestUri → const StdResErrorCond
const StdResErrorCond("lock-token-matches-request-uri")
lockTokenSubmitted → const StdResErrorCond
const StdResErrorCond("lock-token-submitted")
noConflictingLock → const StdResErrorCond
const StdResErrorCond("no-conflicting-lock")
noExternalEntities → const StdResErrorCond
const StdResErrorCond("no-external-entities")
preservedLiveProperties → const StdResErrorCond
const StdResErrorCond("preserved-live-properties")
propfindFiniteDepth → const StdResErrorCond
const StdResErrorCond("propfind-finite-depth")
cannotModifyProtectedProperty → const StdResErrorCond
const StdResErrorCond("cannot-modify-protected-property")

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromName(String name) → StdResErrorCond?

Constants

values → const List<StdResErrorCond>
A constant List of the values in this enum, in order of their declaration.