WebDavStdResError class

Inheritance

Constructors

WebDavStdResError(String message, {List<StdResErrorCond> conditions = const []})

Properties

conditions → List<StdResErrorCond>
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited